tests.factories package — django_analyses 0.0.3 documentation

# tests.factories package

## Subpackages

- tests.factories.input package
  - Subpackages
    - tests.factories.input.definitions package
      - Submodules
      - tests.factories.input.definitions.boolean_input_definition module
      - tests.factories.input.definitions.directory_input_definition module
      - tests.factories.input.definitions.file_input_definition module
      - tests.factories.input.definitions.float_input_definition module
      - tests.factories.input.definitions.input_definition module
      - tests.factories.input.definitions.integer_input_definition module
      - tests.factories.input.definitions.list_input_definition module
      - tests.factories.input.definitions.string_input_definition module
      - Module contents
  - Submodules
  - tests.factories.input.input_specification module
  - Module contents
- tests.factories.pipeline package
  - Submodules
  - tests.factories.pipeline.node module
  - tests.factories.pipeline.pipe module
  - tests.factories.pipeline.pipeline module
  - Module contents

## Submodules

## tests.factories.analysis module

class `tests.factories.analysis.` `AnalysisFactory`

  Bases: `factory.django.DjangoModelFactory`

  `description` = <factory.faker.Faker object>
  `title` = <factory.faker.Faker object>

## tests.factories.analysis_version module

class `tests.factories.analysis_version.` `AnalysisVersionFactory`

  Bases: `factory.django.DjangoModelFactory`

  `analysis` = <factory.declarations.SubFactory object>
  `description` = <factory.faker.Faker object>
  `input_specification` = <factory.declarations.SubFactory object>
  `output_specification` = <factory.declarations.SubFactory object>
  `title` = <factory.faker.Faker object>

## tests.factories.category module

class `tests.factories.category.` `CategoryFactory`

  Bases: `factory.django.DjangoModelFactory`

  `description` = <factory.faker.Faker object>
  `title` = <factory.faker.Faker object>

## tests.factories.run module

class `tests.factories.run.` `RunFactory`

  Bases: `factory.django.DjangoModelFactory`

  `analysis_version` = <factory.declarations.SubFactory object>
  `user` = <factory.declarations.SubFactory object>

## tests.factories.user module

class `tests.factories.user.` `UserFactory`

  Bases: `factory.django.DjangoModelFactory`

  `email` = <factory.faker.Faker object>
  `username` = <factory.faker.Faker object>

## Module contents